//
// IWrapper.cs: Redland Iterator wrapper class
//
// $Id: IWrapper.cs,v 1.4 2005/01/05 11:41:42 edd Exp $
//
// Author:
//	Cesar Lopez Nataren (cesar@ciencias.unam.mx)
//
// (C) 2004, Cesar Lopez Nataren 
//

using System;
using System.Runtime.InteropServices;

namespace Redland {

	public interface IWrapper {		

		HandleRef Handle { get; }
	}
}
